@@ -18,9 +18,9 @@ mvr <- function(X, V)
     N <- attr(X, "Size")
     labels <- attr(X, "Labels")
     if (is.null(labels)) labels <- as.character(1:N)
-    ans <- .C("mvr", as.double(X), as.double(V), as.integer(N),
+    ans <- .C(C_mvr, as.double(X), as.double(V), as.integer(N),
               integer(2*N - 3), integer(2*N - 3), double(2*N - 3),
-              DUP = FALSE, NAOK = TRUE, PACKAGE = "ape")
+              DUP = FALSE, NAOK = TRUE)
     obj <- list(edge = cbind(ans[[4]], ans[[5]]), edge.length = ans[[6]],
                 tip.label = labels, Nnode = N - 2L)
     class(obj) <- "phylo"
@@ -42,9 +42,9 @@ mvrs <- function(X, V, fs = 15)
     N <- attr(X, "Size")
     labels <- attr(X, "Labels")
     if (is.null(labels)) labels <- as.character(1:N)
-    ans <- .C("mvrs", as.double(X), as.double(V), as.integer(N),
+    ans <- .C(C_mvrs, as.double(X), as.double(V), as.integer(N),
               integer(2*N - 3), integer(2*N - 3), double(2*N - 3),
-              as.integer(fs), DUP = FALSE, NAOK = TRUE, PACKAGE = "ape")
+              as.integer(fs), DUP = FALSE, NAOK = TRUE)
     obj <- list(edge = cbind(ans[[4]], ans[[5]]), edge.length = ans[[6]],
                 tip.label = labels, Nnode = N - 2L)
     class(obj) <- "phylo"
